==> openorienteering-mapper_0.6.7.orig.tar.gz: mapper-0.6.7/doc/manual/pages/index.md <==
---
title: User Manual
edited: 26 November 2015
redirect_from:
  - /
  - /Home
---

{% if doxygen %}
**Note:** The [online version](http://openorienteering.github.io/mapper-manual/) of this documentation may contain additions and corrections.
{% endif %}

Contents    {#index_contents}
========

[Map Screen](main_window.md){: .subpage} <br/>
Explanation of the main drawing window.

[Reference](reference.md){: .subpage} <br/>
Toolbar and menu items, including explanations for [all drawing tools](toolbars.md#drawing)

[Starting a new map](new_map.md){: .subpage} <br/>
First steps

[Georeferencing](georeferencing.md){: .subpage} <br />
Defining the relationship between map paper coordinates and real world coordinates system

[Map grid](grid.md){: .subpage} <br />
Showing a helper grid in the map view.

[Templates](templates-index.md){: .subpage} <br/>
Working with templates

[Colors and Symbols](colors_symbols.md){: .subpage} <br/>
Modifying map colors and symbols

[Map Parts](map_parts.md){: .subpage} <br/>
Organizing objects in maps

[Tag Editor](tag_editor.md){: .subpage} <br/>
Attaching arbitrary key-value pairs to objects

[Settings](settings.md){: .subpage} <br/>
Adjusting the program to your preferences.

[Course Design](course_design.md){: .subpage} <br/>
Using the course design symbol set.

[The Mapper App for Android](android-index.md){: .subpage} <br/>
Working with the Android version of Mapper.

[FAQ](faq.md){: .nosubpage} <br/>
Frequently asked questions.


Online resources    {#index_online_resources}
================

[Blog](http://www.openorienteering.org/) <br/>
The latest news from OpenOrienteering.

[Issues list](https://github.com/OpenOrienteering/mapper/issues) <br/>
Submit feedback, bug reports, feature requests, and contributions.

==> openorienteering-mapper_0.7.0.orig.tar.gz: mapper-0.7.0/doc/manual/pages/index.md <==
---
title: User Manual
edited: 4 January 2017
redirect_from:
  - /
  - /Home
---

{% if doxygen %}
**Note:** The [online version](http://www.openorienteering.org/mapper-manual/) of this documentation may contain additions and corrections.
{% endif %}

Contents    {#index_contents}
========

[Map Screen](main_window.md){: .subpage} <br/>
Explanation of the main drawing window.

[Reference](reference.md){: .subpage} <br/>
Toolbar and menu items, including explanations for [all drawing tools](toolbars.md#drawing-toolbar)

[Starting a new map](new_map.md){: .subpage} <br/>
First steps

[Georeferencing](georeferencing.md){: .subpage} <br />
Defining the relationship between map paper coordinates and real world coordinates system

[Map grid](grid.md){: .subpage} <br />
Showing a helper grid in the map view.

[Templates](templates-index.md){: .subpage} <br/>
Working with templates

[Colors and Symbols](colors_symbols.md){: .subpage} <br/>
Modifying map colors and symbols

[Map Parts](map_parts.md){: .subpage} <br/>
Organizing objects in maps

[Tag Editor](tag_editor.md){: .subpage} <br/>
Attaching arbitrary key-value pairs to objects

[Tag Selector](tag_selector.md){: .subpage} <br/>
Selecting objects based on their tags

[Settings](settings.md){: .subpage} <br/>
Adjusting the program to your preferences.

[Course Design](course_design.md){: .subpage} <br/>
Using the course design symbol set.

[The Mapper App for Android](android-index.md){: .subpage} <br/>
Working with the Android version of Mapper.

[FAQ](faq.md){: .nosubpage} <br/>
Frequently asked questions.


Online resources    {#index_online_resources}
================

[Blog](http://www.openorienteering.org/) <br/>
The latest news from OpenOrienteering.

[Issues list](https://github.com/OpenOrienteering/mapper/issues) <br/>
Submit feedback, bug reports, feature requests, and contributions.
